==> HostCMS-6.1.7.tar: modules/structure/i18n/en.php <==
<?php
/**
 * Structure.
 *
 * @package HostCMS 6\Structure
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2012 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Structure',
	'menu' => 'Structure',
	'title' => 'Structure',
	'main_menu' => 'Structure',
	'add' => 'Add',
	'seo_tab' => 'SEO',
	'sitemap_tab' => 'Sitemaps',
	'parent_dir' => 'Structure nodes',
	'edit_success' => 'Structure node information added successfully!',
	'edit_error' => 'Error! Structure node information has not been added!',
	'apply_success' => 'Structure node information modified successfully!',
	'apply_error' => 'Error! Structure node information has not been modified!',
	'markDeleted_success' => 'Structure node deleted successfully!',
	'markDeleted_error' => 'Error! Structure node has not been deleted!',
	'copy_success' => 'Structure node copied successfully!',
	'copy_error' => 'Structure nodes copied successfully!',
	'changeStatus_success' => 'Activity has been changed.',
	'changeStatus_error' => 'Error occurred during changing activity.',
	'changeIndexing_success' => 'Indexing has been changed.',
	'changeIndexing_error' => 'Error occurred during changing indexing.',
	'add_title' => 'Add section',
	'edit_title' => 'Edit structure node',
	'parent_id' => '<acronym title="Section in which this section should be placed">Parent section</acronym>',
	'structure_menu_id' => '<acronym title="Menu containing link to this section">Menu section</acronym>',
	'template_id' => '<acronym title="Select website template. E.g., Main">Website template</acronym>',
	'document_dir_id' => '<acronym title="Website documents section">Documents section</acronym>',
	'document_id' => '<acronym title="Internal document name within management system">Document name</acronym>',
	'show' => '<acronym title="Manages visibility of this section in menu">Display in menu</acronym>',
	'active' => '<acronym title="Manages page activity and sections">Page activity</acronym>',
	"indexing" =>'<acronym title="Manage page indexing">Indexing</acronym>',
	'name' => '<acronym title="Page name in website menu">Page name in menu</acronym>',
	'seo_title' => '<acronym title="Value of meta-tag <title> for page">Page title [Title]</acronym>',
	'seo_description' => '<acronym title="Value of meta-tag <description> for page">Page description [Description]</acronym>',
	'seo_keywords' => '<acronym title="Value of meta-tag <keywords> for page">Keywords [Keywords]</acronym>',
	'url' => '<acronym title="Website section can be an external link">Link to another file</acronym>',
	'sorting' => '<acronym title="Field according to which page should be sorted">Sorting for the current level</acronym>',
	'path' => '<acronym title="Element of path to this page from the parent section. E.g., «about_company»">Section name</acronym>',
	'type' => '<acronym title="Select section type">Section type</acronym>',
	'static_page' => 'Page',
	'typical_dynamic_page' => 'Sample dynamic page',
	'dynamic_page' => 'Dynamic page',
	'siteuser_group_id' => '<acronym title="Group having access to this page">Access group</acronym>',
	'https' => '<acronym title="Use just HTTPS access">HTTPS</acronym>',
	'structure_source' => '<acronym title="PHP code to call dynamic page">Dynamic page</acronym>',
	'structure_config_source' => '<acronym title="Enables to redefine values of page parameters. E.g., value of parameter «title»">Dynamic page settings</acronym>',
	'lib_dir_id' => '<acronym title="Section of sample dynamic pages">Section</acronym>',
	'lib_id' => '<acronym title="Name of sample dynamic page">Page</acronym>',
	'lib_contains_no_parameters' => 'Sample dynamic page contains no parameters.',
	'query_error' => "Error while performing query '%s'",
	'id' => 'Id',
	'site_id' => 'Site Id',
	'properties' => 'Properties',
	'changefreq' => "<acronym title=\"Page refresh rate\">Refresh rate</acronym>",
	'priority' => "<acronym title=\"Priority of this page in relation to other pages\">Priority</acronym>",
	'sitemap_refrashrate_never' => "Never",
	'sitemap_refrashrate_yearly' => "Yearly",
	'sitemap_refrashrate_monthly' => "Monthly",
	'sitemap_refrashrate_weekly' => "Weekly",
	'sitemap_refrashrate_daily' => "Daily",
	'sitemap_refrashrate_hourly' => "Hourly",
	'sitemap_refrashrate_always' => "Always",
	'sitemap_priority_small' => "0 Lowest priority",
	'sitemap_priority_0_1' => "0.1",
	'sitemap_priority_0_2' => "0.2",
	'sitemap_priority_0_3' => "0.3",
	'sitemap_priority_0_4' => "0.4",
	'sitemap_priority_normal' => "0.5 Middle priority",
	'sitemap_priority_0_6' => "0.6",
	'sitemap_priority_0_7' => "0.7",
	'sitemap_priority_0_8' => "0.8",
	'sitemap_priority_0_9' => "0.9",
	'sitemap_priority_above_normal' => "1 Highest priority",
	'additional_params_tab' => 'Additional properties',
	'all' => 'All',
	'like_parent' => 'Like parent',
	// Константы, используемые в классе
	'file_write_error_message' => 'Error while writing file %s. Check access rights to folder!',
	'save_lib_file_error' => 'Unable to save lib file, check access rights.',
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
);

==> HostCMS-6.8.6.tar: modules/structure/i18n/en.php <==
<?php
/**
 * Structure.
 *
 * @package HostCMS
 * @subpackage Structure
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2018 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Structure',
	'menu' => 'Structure',
	'title' => 'Structure',
	'main_menu' => 'Structure',
	'add' => 'Add',
	'seo_tab' => 'SEO',
	'sitemap_tab' => 'Sitemaps',
	'parent_dir' => 'Structure nodes',
	'edit_success' => 'Structure node information added successfully!',
	'edit_error' => 'Error! Structure node information has not been added!',
	'apply_success' => 'Structure node information modified successfully!',
	'apply_error' => 'Error! Structure node information has not been modified!',
	'markDeleted_success' => 'Structure node deleted successfully!',
	'markDeleted_error' => 'Error! Structure node has not been deleted!',
	'copy_success' => 'Structure node copied successfully!',
	'copy_error' => 'Structure nodes copied successfully!',
	'changeStatus_success' => 'Activity has been changed.',
	'changeStatus_error' => 'Error occurred during changing activity.',
	'changeIndexing_success' => 'Indexing has been changed.',
	'changeIndexing_error' => 'Error occurred during changing indexing.',
	'add_title' => 'Add section',
	'edit_title' => 'Edit structure node',
	'parent_id' => 'Parent section',
	'structure_menu_id' => 'Menu section',
	'template_id' => '<acronym title="Select website template. E.g., Main">Website template</acronym>',
	'document_dir_id' => 'Documents section',
	'document_id' => 'Document name',
	'show' => 'Display in menu',
	'active' => 'Active',
	"indexing" =>'Indexing',
	'name' => 'Page name in menu',
	'seo_title' => 'Title',
	'seo_description' => 'Description',
	'seo_keywords' => 'Keywords',
	'url' => '<acronym title="Website section can be an external link">Link to another file</acronym>',
	'sorting' => 'Sort',
	'path' => '<acronym title="Part of path from the parent structure,  e.g. about-company">Path</acronym>',
	'type' => 'Section type',
	'static_page' => 'Page',
	'typical_dynamic_page' => 'Sample dynamic page',
	'dynamic_page' => 'Dynamic page',
	'link' => 'Link',
	'document_text' => 'Sample dynamic page text',
	'siteuser_group_id' => 'Access group',
	'https' => 'HTTPS',
	'structure_source' => 'Dynamic page',
	'structure_config_source' => '<acronym title="Enables to redefine values of page parameters. E.g., value of parameter «title»">Dynamic page settings</acronym>',
	'lib_dir_id' => 'Section',
	'lib_id' => 'Page',
	'lib_contains_no_parameters' => 'Sample dynamic page contains no parameters.',
	'query_error' => "Error while performing query '%s'",
	'id' => 'ID',
	'site_id' => 'Site Id',
	'properties' => 'Properties',
	'changefreq' => "Refresh rate",
	'priority' => "Priority",
	'sitemap_refrashrate_never' => "Never",
	'sitemap_refrashrate_yearly' => "Yearly",
	'sitemap_refrashrate_monthly' => "Monthly",
	'sitemap_refrashrate_weekly' => "Weekly",
	'sitemap_refrashrate_daily' => "Daily",
	'sitemap_refrashrate_hourly' => "Hourly",
	'sitemap_refrashrate_always' => "Always",
	'sitemap_priority_small' => "0 Lowest priority",
	'sitemap_priority_0_1' => "0.1",
	'sitemap_priority_0_2' => "0.2",
	'sitemap_priority_0_3' => "0.3",
	'sitemap_priority_0_4' => "0.4",
	'sitemap_priority_normal' => "0.5 Middle priority",
	'sitemap_priority_0_6' => "0.6",
	'sitemap_priority_0_7' => "0.7",
	'sitemap_priority_0_8' => "0.8",
	'sitemap_priority_0_9' => "0.9",
	'sitemap_priority_above_normal' => "1 Highest priority",
	'additional_params_tab' => 'Additional properties',
	'all' => 'All',
	'like_parent' => 'Like parent',
	// Константы, используемые в классе
	'file_write_error_message' => 'Error while writing file %s. Check access rights to folder!',
	'save_lib_file_error' => 'Unable to save lib file, check access rights.',
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
);
